@@ -35,6 +35,11 @@
 
   2004/09/13 - More and more fix for linux's threads - Nelson Murilo
 
+  2005/02/23 - More and more and more fix for linux's threads - Nelson Murilo
+
+  2005/10/28 - Bug fix for FreeBSD: chkproc was sending a SIGXFSZ (kill -25)
+               to init, causing a reboot.  Patch by Nelson Murilo.
+               Thanks to Luiz E. R. Cordeiro.
 */
 
 #if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__sun)
@@ -54,9 +59,10 @@ int main (){ return 0; }
 #endif
 
 #define PS_SUN 0
-#define PS_COM 1
-#define PS_LNX 2
-#define PS_MAX 2
+#define PS_LOL 1
+#define PS_COM 2
+#define PS_LNX 3
+#define PS_MAX 3
 
 #if defined(__sun)
 #define FIRST_PROCESS 0
@@ -68,7 +74,8 @@ int main (){ return 0; }
 
 static char *ps_cmds[] = {
 	    "ps -edf",
-	    "ps mauxw",
+	    "ps auxw",
+	    "ps mauxw 2>&1 ",
             "ps auxw -T|tr -s ' '|cut -d' ' -f2-",
           };
 
@@ -95,7 +102,7 @@ int main(int argc, char **argv)
    psinfo_t psbuf;
 #endif
 
-   pv = verbose = 0; 
+   pv = verbose = 0;
 
    if (!proc)
    {
@@ -108,12 +115,12 @@ int main(int argc, char **argv)
 	verbose++;
       else if (!memcmp(argv[i], "-?", 2))
       {
-	printf("Usage: %s [-v] [-v]\n", argv[0]);
+	printf("Usage: %s [-v] [-v] -p <num>\n", argv[0]);
 	return 0;
       }
 #if defined(__linux__)
       else if (!memcmp(argv[i], "-p", 2))
-        if (i+1 < argc) 
+        if (i+1 < argc)
            pv = atoi(argv[++i]);
         else
         {
@@ -134,7 +141,7 @@ int main(int argc, char **argv)
 /*  printf("pv = %d\n\r", pv); /* -- DEBUG */
 #endif
 
-/* printf("pscmd = %s\n\r", pscmd); /* -- DEBUG */ 
+/* printf("pscmd = %s\n\r", pscmd); /* -- DEBUG */
    if (!(ps = popen(pscmd, "r")))
    {
        perror("ps");
@@ -152,10 +159,15 @@ int main(int argc, char **argv)
      fgets(buf, MAX_BUF, ps); /* Skip header */
      if (!isalpha(*buf) && pv != PS_LNX)
      {
+	if (pv != PS_LOL)
+	   execlp(argv[0], argv[0], "-p 1", NULL);
         fprintf(stderr, "OooPS!\n");
         exit(2);
      }
    }
+   if (!memcmp(buf, "ps:", 3) && (pv != PS_LOL))
+      execlp(argv[0], argv[0], "-p 1", NULL);
+
    for (i = FIRST_PROCESS; i <= MAX_PROCESSES; i++) { /* Init matrix */
      psproc[i] = dirproc[i] = 0;
 #if defined(__linux__)
@@ -286,12 +298,14 @@ int main(int argc, char **argv)
       printf("You have % 5d process hidden for readdir command\n", retdir);
    if (retps)
       printf("You have % 5d process hidden for ps command\n", retps);
+#if defined(__linux__)
    kill(1, 100); /*  Check for SIGINVISIBLE Adore signal */
-   if ( errno == 3)
+   if (kill (1, 25) > 0 && errno == 3)
    {
       printf("SIGINVISIBLE Adore found\n");
       retdir+= errno;
    }
+#endif
    return (retdir+retps);
 }
 #endif
