@@ -15,6 +15,8 @@
    Nelson Murilo, nelson@pangeia.com.br
    07/08/04 - fix del counter value (Thanks to Dietrich Raisin)
    Nelson Murilo, nelson@pangeia.com.br
+   09/12/05 - fix Segfault (Thanks to Jrmie Andri)
+   Nelson Murilo, nelson@pangeia.com.br
 */
 
 
@@ -63,7 +65,8 @@ int main(int argc, char*argv[]) {
 	start_time=0;
 
 	gettimeofday(&mytime, &dummy);
-	act_time=mytime.tv_sec;
+       act_time=mytime.tv_sec;
+       wtmpfile[127]='\0';
        memcpy(wtmpfile, WTMP_FILENAME, 127);
        if ( argc == 3 && !memcmp("-f", argv[1], 2) && *argv[2])
           memcpy(wtmpfile, argv[2], 127);
